<?php

namespace Drupal\health_check_url\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Response;

/**
 * Controller for route that returns health check url type.
 */
class HealthCheckController extends ControllerBase {


  protected $string;

  protected $type;

  /**
   * Constructs a new HealthCheckController object.
   *
   * @param \Drupal\Core\PageCache\ResponsePolicy\KillSwitch $kill_switch
   *   The page cache kill switch.
   */
  public function __construct() {

    $config = \Drupal::config('health_check_url.settings');
    $this->string = $config->get('string') != "" ? $config->get('string') : "Passed";
    $this->type = $config->get('type') != "" ? $config->get('type') : "timestamp";
  }

  

  /**
   * timestamp health check
   *
   * @return \Symfony\Component\HttpFoundation\Response
   */
  public function healthCheckUrl() {
    // Disable page cache
    $options = ["timestamp" => time(), 
                "string" =>  $this->string, 
                "stringWithTimestamp" => $this->string.' - ' . time(),
                "stringWithDateTime" => $this->string.' ' . strftime("at %T on %D"),
                "stringWithDateTimestamp" => $this->string.' ' . strftime("at %T on %D") . ' (' . time() . ')',
               ];
    return $this->buildResponse($options[$this->type]);
  }

  
  /**
   * Build response
   *
   * @return array
   */
  public function buildResponse($string) {
     $response = new Response();
     $response->headers->set('Content-Type', 'text/plain');
     $response->setContent($string);
     return $response;
  }
}
