<?php
/**
 * @file
 * Contains \Drupal\health_check_url\Form\HealthCheckSettingsForm
 */
namespace Drupal\health_check_url\Form;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Path\PathValidator;
/**
 * Configure health settings for this site.
 */
class HealthCheckSettingsForm extends ConfigFormBase {
  /** 
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'health_check_url_settings';
  }
  /** 
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'health_check_url.settings',
    ];
  }
  /** 
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('health_check_url.settings');
    $options = ["timestamp" => time(), 
                "string" =>  $config->get('string'), 
                "stringWithTimestamp" => $config->get('string').' - ' . time(),
                "stringWithDateTime" => $config->get('string').' ' . strftime("at %T on %D"),
                "stringWithDateTimestamp" => $config->get('string').' ' . strftime("at %T on %D") . ' (' . time() . ')',
               ];
    $form['type'] = array(
    '#title' => t('Response Type'),
    '#type' => 'radios',
    '#options' => $options,
    '#default_value' => $config->get('type'),
    );

    $form['string'] = array(
    '#title' => t('String'),
    '#type' => 'textfield',
    '#description' => t("Enter the string to display in output. works only if string types is selected in the above Response type "),
    '#default_value' => $config->get('string'),
    );
    
    $form['endpoint'] = array(
    '#title' => t('Endpoint'),
    '#type' => 'textfield',
    '#description' => t("Enter the path for health check up "),
    '#default_value' => $config->get('endpoint'),
    );

    $form['maintainence_access'] = array(
    '#title' => t('Accessible on maintainence mode'),
    '#type' => 'checkbox',
    '#description' => t(" Defines whether the endpoint is accessible when site is on maintainence mode "),
    '#default_value' => $config->get('maintainence_access'),
    );
    return parent::buildForm($form, $form_state);
  }


   /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if ($form_state->isValueEmpty('endpoint')) {
      $form_state->setValueForElement($form['endpoint'], '/health');
    }

    if ($form_state->isValueEmpty('string')) {
      $form_state->setValueForElement($form['string'], 'Passed');
    }
        
    if (($value = $form_state->getValue('endpoint')) && $value[0] !== '/') {
      $form_state->setErrorByName('endpoint', $this->t("The path '%path' has to start with a slash.", ['%path' => $form_state->getValue('endpoint')]));
    }
  }

  /** 
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('health_check_url.settings')
      ->set('type', $form_state->getValue('type'))
      ->set('string',$form_state->getValue('string'))
      ->set('endpoint',$form_state->getValue('endpoint'))
      ->set('maintainence_access',$form_state->getValue('maintainence_access')) 
      ->save();
    \Drupal::service("router.builder")->rebuild();
    parent::submitForm($form, $form_state);
  }
}
